# Static Files

## Wake Vortex (Emitter) Categories

### Sources

* The 1090 Megahertz Riddle: [Aircraft identification and category](https://mode-s.org/decode/content/ads-b/2-identification.html)
* ADS-B Exchange: [Emitter Category ADS-B DO-260B 2.2.3.2.5.2](https://www.adsbexchange.com/emitter-category-ads-b-do-260b-2-2-3-2-5-2/)
* adsbtype: [Documentation - AcCat](https://pkg.go.dev/kreklow.us/go/go-adsb/adsbtype#AcCat)